@@ -1,9 +1,8 @@
+import json
+import os
 import sys
-from enum import Enum
 from typing import Callable, Optional
 
-from rconfig import _serialize_value_to_json
-
 
 try:
     import yaml
@@ -11,18 +10,14 @@ except ImportError:
     yaml = None
 
 
-class ScriptFormat(Enum):
-    inline: str = 'inline'
-    new_line: str = 'new_line'
-
-
 def to_bash(
         data: dict,
-        format: ScriptFormat = ScriptFormat.inline,  # pylint: disable=W0622
-        serializer: Callable = _serialize_value_to_json,
+        inline: bool = False,
+        serializer: Callable = (
+            lambda x: x if isinstance(x, str) else json.dumps(x)
+        ),
         prefix: str = '',
 ) -> Optional[str]:
-    inline = ScriptFormat.inline == format
     bash = str()
     for key, value in data.items():
         line = f'{prefix}{key}={serializer(value)!r}'
@@ -32,7 +27,14 @@ def to_bash(
     return f'export {bash}' if inline else bash.rstrip('\n')
 
 
-def to_yaml(data: dict, prefix: str = '') -> Optional[str]:
+def to_yaml(
+        data: dict,
+        shallow: bool = False,
+        serializer: Callable = (
+            lambda x: json.dumps(x) if isinstance(x, (dict, list)) else x
+        ),
+        prefix: str = '',
+) -> Optional[str]:
     if yaml is None:
         sys.stderr.write(
             'Missing yaml package.\nRun pip install "rconfig[yaml]"'
@@ -40,6 +42,33 @@ def to_yaml(data: dict, prefix: str = '') -> Optional[str]:
     if not data:
         return None
     return yaml.dump(
-        {f'{prefix}{k}': v for k, v in data.items()},
+        {
+            f'{prefix}{k}': serializer(v) if shallow else v
+            for k, v in data.items()
+        },
         default_flow_style=False,
     )
+
+
+def to_json(
+        data: dict,
+        pretty: bool = False,
+        prefix: str = '',
+) -> Optional[str]:
+    if not data:
+        return None
+    return json.dumps(
+        {f'{prefix}{k}': v for k, v in data.items()},
+        indent=4 if pretty else None,
+    )
+
+
+def set_environment_variables(
+        data: dict,
+        prefix: str = '',
+        serializer: Callable = (
+            lambda x: x if isinstance(x, str) else json.dumps(x)
+        ),
+) -> None:
+    for key, value in data.items():
+        os.environ[f'{prefix}{key}'] = serializer(value)
